package com.fjhx.mapper.check;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fjhx.entity.check.CheckInfo;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 盘点 Mapper 接口
 * </p>
 *
 * @author ${author}
 * @since 2022-11-01
 */
public interface CheckInfoMapper extends BaseMapper<CheckInfo> {

    Page<Map<String, Object>> getPage(@Param("page") Page<Object> page, @Param("ew") QueryWrapper<Object> wrapper);

    Map<String, Object> monthlyStatistics(@Param("ew") QueryWrapper<Object> wrapper);

    List<Map<String, Object>> houseCount(@Param("ew") QueryWrapper<Object> wrapper);

    Page<Map<String, Object>> webPage(@Param("page") Page<Object> page, @Param("ew") QueryWrapper<Object> wrapper);

    List<Map<String, Object>> errorTagTechnologyTypeCount(@Param("ew") QueryWrapper<Object> wrapper);

    List<Map<String, Object>> errorTagPurposeCount(@Param("ew") QueryWrapper<Object> wrapper);

    List<Map<String, Object>> errorTagHandleTypeCount(@Param("ew") QueryWrapper<Object> wrapper);

    Page<Map<String, Object>> errorTagPage(@Param("page") Page<Object> page, @Param("ew") QueryWrapper<Object> wrapper);

    List<String> errorMaterialPurpose(@Param("ew") QueryWrapper<Object> wrapper);

    Page<Map<String, Object>> errorMaterialPage(@Param("page") Page<Object> page, @Param("ew") QueryWrapper<Object> wrapper);

    Page<Map<String, Object>> errorMaterialTagPage(@Param("page") Page<Object> page, @Param("ew") QueryWrapper<Object> wrapper);

    Page<Map<String, Object>> materialDetailPage(@Param("page") Page<Object> page, @Param("ew") QueryWrapper<Object> wrapper);

    Map<String, Object> checkResultStatistics(@Param("ew") QueryWrapper<Object> wrapper);

}
